Learn R Programming

risk.assessr (version 3.0.1)

check_cran_package: Check if a Package Exists on CRAN

Description

This function checks if a given package is available on CRAN.

Usage

check_cran_package(package_name)

Value

A logical value: `TRUE` if the package exists on CRAN, `FALSE` otherwise.

Arguments

package_name

A character string specifying the name of the package to check.

Examples

Run this code
if (FALSE) {
# Check if the package "ggplot2" exists on CRAN
check_cran_package("ggplot2")
}

Run the code above in your browser using DataLab