Learn R Programming

risk.assessr (version 3.0.1)

check_suggested_exp_funcs: Function to check suggested exported functions

Description

This function checks the exported functions of target package against the exported functions of Suggested dependencies to see if any Suggested packages should be in Imports in the DESCRIPTION file

Usage

check_suggested_exp_funcs(pkg_name, pkg_source_path, suggested_deps)

Value

- data frame with results of Suggests check

Arguments

pkg_name

- name of the target package

pkg_source_path

- source of the target package

suggested_deps

- dependencies in Suggests