Learn R Programming

risk.assessr (version 3.0.1)

get_pkg_desc: Read Description file and parse the package name and version

Description

Read Description file and parse the package name and version

Usage

get_pkg_desc(pkg_source_path, fields = NULL)

Value

list with package description

Arguments

pkg_source_path

path to package source code (untarred)

fields

- select specified elements from description