get_pubmed_by_year: Get Annual PubMed Article Counts for a Search Term
Description
This function queries the NCBI E-utilities API to retrieve the number of PubMed articles
published each year over a specified number of past years for a given search term or package name.