adapted from mpn.scorecard
get_toplevel_assignments(pkg_source_path)A data.frame with the columns `function` and `code_script` with a row for every top-level object defined in the package.
a file path pointing to an unpacked/untarred package directory
This is primarily for getting all _functions_, but it also returns top-level declarations, regardless of type. This is intentional, because we also want to capture any global variables or anything else that could be potentially exported by the package.