Learn R Programming

risk.assessr (version 3.0.1)

parse_bioconductor_releases: Parse Bioconductor Release Announcements

Description

This function extracts Bioconductor release details such as version number, release date, number of software packages, and required R version from the release announcements HTML page.

Usage

parse_bioconductor_releases(html_content)

Value

A list of lists containing Bioconductor release details: release version, date, number of software packages, and corresponding R version.

Arguments

html_content

The parsed HTML document from `fetch_bioconductor_releases`.

Examples

Run this code
if (FALSE) {
html_content <- fetch_bioconductor_releases()
release_data <- parse_bioconductor_releases(html_content)
print(release_data)
}

Run the code above in your browser using DataLab