Learn R Programming

risk.assessr (version 3.0.1)

parse_package_info: Parse Package Information from CRAN Archive

Description

This function retrieves the package archive information from the CRAN Archive.

Usage

parse_package_info(name)

Value

A character string containing the raw HTML content of the package archive page, or `NULL` if the request fails or the package is not found.

Arguments

name

A character string specifying the name of the package to fetch information for.

Examples

Run this code
if (FALSE) {
# Fetch package archive information for "dplyr"
parse_package_info("dplyr")

}

Run the code above in your browser using DataLab