Learn R Programming

risk.assessr (version 3.0.1)

risk.assessr-package: risk.assessr: Assessing Package Risk Metrics

Description

logo

A reliable and validated tool that captures detailed risk metrics such as R 'CMD' check, test coverage, traceability matrix, documentation, dependencies, reverse dependencies, suggested dependency analysis, repository data, and enhanced reporting for R packages that are local or stored on remote repositories such as GitHub, CRAN, and Bioconductor.

Arguments

Author

Maintainer: Edward Gillian edward.gillian-ext@sanofi.com (ORCID)

Authors:

Other contributors:

  • Sanofi [copyright holder, funder]

See Also