check_and_fetch_cran_package: Check and Fetch CRAN Package
Description
This function checks if a package exists on CRAN and retrieves the corresponding package URL and version details.
If a specific version is not provided, the latest version is used.
if (FALSE) {
# Check and fetch a specific version of "ggplot2"result <- check_and_fetch_cran_package("ggplot2", package_version = "3.3.5")
print(result)
}