powered by
This function checks if a given package is available on CRAN.
check_cran_package(package_name)
A logical value: `TRUE` if the package exists on CRAN, `FALSE` otherwise.
A character string specifying the name of the package to check.
if (FALSE) { # Check if the package "ggplot2" exists on CRAN check_cran_package("ggplot2") }
Run the code above in your browser using DataLab