This function checks the exported functions of target package against the exported functions of Suggested dependencies to see if any Suggested packages should be in Imports in the DESCRIPTION file
check_suggested_exp_funcs(pkg_name, pkg_source_path, suggested_deps)- data frame with results of Suggests check
- name of the target package
- source of the target package
- dependencies in Suggests