Counts the total number of commits from the last `months` months using a data frame with weekly commit data (column `week_start`).
Usage
count_commits_last_months(df, months = 1, today = Sys.Date())Examples
if (FALSE) { # \dontrun{
df <- get_commits_since("tidyverse", "ggplot2", years = 1)
count_commits_last_months(df, months = 3)
} # }