powered by
Counts the total number of commits from the last `months` months using a data frame with weekly commit data (column `week_start`).
count_commits_last_months(df, months = 1, today = Sys.Date())
Integer. Total number of commits in the time window.
A data frame with `week_start` (Date) and `n_commits` (int) columns.
Integer. Number of months to look back (default is 1).
today's date.default is Sys.Date()
if (FALSE) { df <- get_commits_since("tidyverse", "ggplot2", years = 1) count_commits_last_months(df, months = 3) }
Run the code above in your browser using DataLab