Learn R Programming

risk.assessr (version 3.0.1)

cran_revdep: Find Reverse Dependencies of a CRAN Package

Description

This function finds the reverse dependencies of a CRAN package, i.e., packages that depend on the specified package.

Usage

cran_revdep(
  pkg,
  dependencies = c("Depends", "Imports", "Suggests", "LinkingTo"),
  recursive = FALSE,
  ignore = NULL,
  installed = NULL
)

Value

deps - A sorted character vector of package names that depend on the specified package.

Arguments

pkg

A character string representing the name of the package.

dependencies

A character vector specifying the types of dependencies to consider. Default is c("Depends", "Imports", "Suggests", "LinkingTo").

recursive

A logical value indicating whether to find dependencies recursively. Default is FALSE.

ignore

A character vector of package names to ignore. Default is NULL.

installed

A matrix of installed packages.

Examples

Run this code
if (FALSE) {
cran_revdep("ggplot2")
}

Run the code above in your browser using DataLab