powered by
This function finds the reverse dependencies of a CRAN package, i.e., packages that depend on the specified package.
cran_revdep( pkg, dependencies = c("Depends", "Imports", "Suggests", "LinkingTo"), recursive = FALSE, ignore = NULL, installed = NULL )
deps - A sorted character vector of package names that depend on the specified package.
A character string representing the name of the package.
A character vector specifying the types of dependencies to consider. Default is c("Depends", "Imports", "Suggests", "LinkingTo").
A logical value indicating whether to find dependencies recursively. Default is FALSE.
A character vector of package names to ignore. Default is NULL.
A matrix of installed packages.
if (FALSE) { cran_revdep("ggplot2") }
Run the code above in your browser using DataLab