powered by
This function identifies packages that depend on the specified packages, considering various types of dependencies (e.g., strong, most, all).
dependsOnPkgs( pkgs, dependencies = "most", recursive = TRUE, lib.loc = NULL, installed = NULL )
A character vector of package names that depend on the specified packages.
A character vector of package names to check dependencies for.
A character string specifying the types of dependencies to consider. Can be "strong", "most", "all", or a custom vector of dependency types.
A logical value indicating whether to recursively check dependencies.
A character vector of library locations to search for installed packages.
A matrix of installed packages, obtained from cran_packages function. .
if (FALSE) { installed <- cran_packages() dependsOnPkgs("here", installed = installed) }
Run the code above in your browser using DataLab