powered by
This function retrieves the installed version of a specified R package. If the package is not installed, returns `NA`.
extract_package_version(package_name)
A character string representing the installed package version, or `NA` if the package is not found.
A character string specifying the name of the package.
if (FALSE) { extract_package_version("dplyr") # 1.1.4 }
Run the code above in your browser using DataLab