Learn R Programming

risk.assessr (version 3.0.1)

fetch_all_dependencies: Fetch All Dependencies for a Package

Description

This function builds and retrieves the full dependency tree for a given R package.

Usage

fetch_all_dependencies(package_name)

Value

A nested list representing the dependency tree of the package.

Arguments

package_name

A character string specifying the name of the package.

Examples

Run this code
if (FALSE) {
fetch_all_dependencies("ggplot2")
}

Run the code above in your browser using DataLab