powered by
This function builds and retrieves the full dependency tree for a given R package.
fetch_all_dependencies(package_name)
A nested list representing the dependency tree of the package.
A character string specifying the name of the package.
if (FALSE) { fetch_all_dependencies("ggplot2") }
Run the code above in your browser using DataLab