powered by
This function fetches all commits from a specified GitHub repository using the GitHub API and returns a data frame with weekly commit counts.
get_commits_since(owner, repo, years = 1)
A data frame with four columns:
Start date of the week (class Date).
Date
Year of the commits.
Month of the commits.
Number of commits during the week.
Character. The GitHub username or organization that owns the repository.
Character. The name of the GitHub repository.
Numeric. Number of years to look back from today's date (default is 1).
if (FALSE) { # Get commit counts for the past year get_commits_since(owner = "tidyverse", repo = "ggplot2") }
Run the code above in your browser using DataLab