powered by
This function extracts the version information of imported and suggested packages for a given package from the current R session.
get_session_dependencies(deps_list)
A list with two elements:
A named list of packages in the "Imports" section along with their corresponding versions
A named list of packages in the "Suggests" section along with their corresponding versions
A data frame containing the dependency information of the package (provided by calc_dependencies function)
# \donttest{ deps_list <- data.frame( package = c("dplyr", "ggplot2", "testthat", "knitr"), type = c("Imports", "Imports", "Suggests", "Suggests") ) get_session_dependencies(deps_list) # }
Run the code above in your browser using DataLab