R/dependency_tree.R
is_base.Rd
This function determines whether a given package is a base or recommended package using CRAN metadata.
is_base(pkg)
A character string representing the name of the package.
A logical value: `TRUE` if the package is a base or recommended package, `FALSE` otherwise.
if (FALSE) { # \dontrun{ is_base("stats") # TRUE is_base("ggplot2") # FALSE } # }