Learn R Programming

risk.assessr (version 3.0.1)

is_base: Check if a Package is a Base or Recommended R Package

Description

This function determines whether a given package is a base or recommended package using CRAN metadata.

Usage

is_base(pkg)

Value

A logical value: `TRUE` if the package is a base or recommended package, `FALSE` otherwise.

Arguments

pkg

A character string representing the name of the package.

Examples

Run this code
if (FALSE) {
is_base("stats")     # TRUE
is_base("ggplot2")   # FALSE
}

Run the code above in your browser using DataLab