powered by
This function determines whether a given package is a base or recommended package using CRAN metadata.
is_base(pkg)
A logical value: `TRUE` if the package is a base or recommended package, `FALSE` otherwise.
A character string representing the name of the package.
if (FALSE) { is_base("stats") # TRUE is_base("ggplot2") # FALSE }
Run the code above in your browser using DataLab