Parse HTML Content for Package Versions
Source:R/get_bioconductor_data.R, R/get_package_host_info.R
parse_html_version.RdThis function extracts version information from an HTML page listing available versions of a Bioconductor package.
This function extracts version information from the HTML content of a CRAN archive page.
Value
A list of lists containing package details such as package name, version, link, date, and size. Returns an empty list if no versions are found.
A list of lists, where each sublist contains: - `package_name`: package name. - `package_version`: package version. - `link`: link to the package tarball. - `date`: The date associated with the package version. - `size`: The size of the package tarball.
Examples
if (FALSE) { # \dontrun{
parse_html_version(html_content, "GenomicRanges")
} # }
if (FALSE) { # \dontrun{
html_content <- parse_package_info("dplyr")
parse_html_version(html_content, "dplyr")
} # }