powered by
This function retrieves the package archive information from the CRAN Archive.
parse_package_info(name)
A character string containing the raw HTML content of the package archive page, or `NULL` if the request fails or the package is not found.
A character string specifying the name of the package to fetch information for.
if (FALSE) { # Fetch package archive information for "dplyr" parse_package_info("dplyr") }
Run the code above in your browser using DataLab